////////////////////////////////////////////////////////////////////////////////
//
// (C) 2010 Sarah Eris Horsley Caffee
//
// mandelbrot - A simple Mandelbrot Set viewer.
//
// EventHandler.h
// EventHandler class definition.  This is a virtual class that is meant to be
// an interface implemented by an application class.  It does, though, provide
// default implementations of it's methods so that unused events can be quietly
// ignored.
//
////////////////////////////////////////////////////////////////////////////////

#ifndef EVENTHANDLER_H
#define EVENTHANDLER_H

#include "SDL.h"

class EventHandler
   {
   public:

   EventHandler();
   virtual ~EventHandler();

#ifndef USE_SDL_WAITEVENT
   virtual int wait_event_timeout(SDL_Event * event, Uint32 timeout);
#endif

   virtual void on_event(SDL_Event * event);

   virtual void on_InputFocus();
   virtual void on_InputBlur();
   virtual void on_KeyDown(SDLKey sym, SDLMod mod, Uint16 unicode);
   virtual void on_KeyUp(SDLKey sym, SDLMod mod, Uint16 unicode);
   virtual void on_MouseFocus();
   virtual void on_MouseBlur();
   virtual void on_MouseMove(int mx, int my, int relx, int rely, bool left, bool right, bool middle);
   virtual void on_MouseWheel(bool up, bool down);
   virtual void on_LButtonDown(int mx, int my);
   virtual void on_LButtonUp(int mx, int my);
   virtual void on_RButtonDown(int mx, int my);
   virtual void on_RButtonUp(int mx, int my);
   virtual void on_MButtonDown(int mx, int my);
   virtual void on_MButtonUp(int mx, int my);
   virtual void on_JoyAxis(Uint8 ehich, Uint8 axis, Sint16 value);
   virtual void on_JoyButtonDown(Uint8 which, Uint8 button);
   virtual void on_JoyButtonUp(Uint8 which, Uint8 button);
   virtual void on_JoyHat(Uint8 which, Uint8 hat, Uint8 value);
   virtual void on_JoyBall(Uint8 which, Uint8 ball, Sint16 xrel, Sint16 yrel);
   virtual void on_Minimize();
   virtual void on_Restore();
   virtual void on_Resize(int w, int h);
   virtual void on_Expose();
   virtual void on_Exit();
   virtual void on_User(Uint8 type, int code, void * data1, void * data2);
   };

#endif
